@@ -15,6 +15,9 @@ use opentelemetry_0_15_pkg as opentelemetry;
 #[cfg(feature = "opentelemetry_0_16")]
 use opentelemetry_0_16_pkg as opentelemetry;
 
+#[cfg(feature = "opentelemetry_0_17")]
+use opentelemetry_0_17_pkg as opentelemetry;
+
 #[cfg(feature = "opentelemetry_0_13")]
 pub use tracing_opentelemetry_0_12_pkg as tracing_opentelemetry;
 
@@ -27,6 +30,9 @@ pub use tracing_opentelemetry_0_14_pkg as tracing_opentelemetry;
 #[cfg(feature = "opentelemetry_0_16")]
 pub use tracing_opentelemetry_0_16_pkg as tracing_opentelemetry;
 
+#[cfg(feature = "opentelemetry_0_17")]
+pub use tracing_opentelemetry_0_17_pkg as tracing_opentelemetry;
+
 use opentelemetry::global;
 use opentelemetry::propagation::Injector;
 use tracing_opentelemetry::OpenTelemetrySpanExt;
